#
# spec file for package kanku
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kanku_user   kankurun
%define kanku_group  kanku
%define kanku_vardir /var/lib/kanku/

Name:           kanku
# Version gets set by obs-service-tar_scm
Version:        0.16.2
Release:        1.1
License:        GPL-3.0-only
Summary:        Development and continuous integration
URL:            https://github.com/M0ses/kanku
Group:          Productivity/Networking/Web/Utilities
Source:         %{name}-%{version}.tar.xz
BuildArch:      noarch
# Build only for supported arch. See 'etc/templates/default-vm.tt2.$ARCH'
ExclusiveArch:  aarch64 x86_64 %{ix86}
BuildRequires:  fdupes
BuildRequires:  perl-macros
BuildRequires:  systemd-rpm-macros

%if 0%{?suse_version}
BuildRequires:  sysuser-tools
%endif

# perl requires for %check
BuildRequires:  perl(Const::Fast)
BuildRequires:  perl(Config::Tiny)
BuildRequires:  perl(DBIx::Class)
BuildRequires:  perl(DBIx::Class::Fixtures)
BuildRequires:  perl(DBIx::Class::Migration)
BuildRequires:  perl(Dancer2)
BuildRequires:  perl(Dancer2::Plugin)
BuildRequires:  perl(Dancer2::Plugin::Auth::Extensible)
BuildRequires:  perl(Dancer2::Plugin::Auth::Extensible::Provider::DBIC)
BuildRequires:  perl(Dancer2::Plugin::DBIC)
BuildRequires:  perl(Dancer2::Plugin::REST)
BuildRequires:  perl(Dancer2::Plugin::WebSocket)
BuildRequires:  perl(Expect)
BuildRequires:  perl(File::HomeDir)
BuildRequires:  perl(File::LibMagic)
BuildRequires:  perl(IO::Interactive)
BuildRequires:  perl(IO::Uncompress::UnXz)
BuildRequires:  perl(IPC::Run)
BuildRequires:  perl(JSON::XS)
BuildRequires:  perl(Log::Log4perl)
BuildRequires:  perl(Moose)
BuildRequires:  perl(MooseX::App)
BuildRequires:  perl(MooseX::Singleton)
BuildRequires:  perl(Net::IP)
BuildRequires:  perl(Net::OBS::Client) >= 0.1.0
BuildRequires:  perl(Libssh::Session)
BuildRequires:  perl(Path::Class)
BuildRequires:  perl(Plack)
BuildRequires:  perl(Sys::Virt)
BuildRequires:  perl(Template)
BuildRequires:  perl(Template::Plugin::Filter::ANSIColor)
BuildRequires:  perl(Term::ReadKey)
BuildRequires:  perl(Test::Simple)
BuildRequires:  perl(XML::Structured)
BuildRequires:  perl(XML::XPath)
BuildRequires:  perl(YAML::PP)
# DBD::SQLite is also provided by perl-DBD-SQLite-Amalgamation
# but perl-DBD-SQLite-Amalgamation is breaks with SQL syntax errors
# at job_histroy_sub table
BuildRequires:  perl-DBD-SQLite
BuildRequires:  desktop-file-utils
BuildRequires:  libvirt-daemon
BuildRequires:  shared-mime-info
BuildRequires:  perl(Archive::Cpio)
BuildRequires:  perl(LWP::Protocol::https)
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(Mail::Sendmail)
BuildRequires:  perl(Net::AMQP::RabbitMQ)
BuildRequires:  perl(UUID)

Requires:       kanku-cli = %{version}
Requires:       kanku-dispatcher = %{version}
Requires:       kanku-scheduler = %{version}
Requires:       kanku-triggerd = %{version}
Requires:       kanku-web = %{version}
Requires:       kanku-worker = %{version}

%description
kanku is a utility for integration of kiwi images built
by the Open Build Service (OBS) in a development and testing workflow.

It provides a framework for automation of setups,
e.g. to prepare development environments or run simple tests.

%prep
%autosetup -p1

%build
%if 0%{?suse_version}
%sysusers_generate_pre dist/system-user-%{kanku_user}.conf %{kanku_user} system-user-%{kanku_user}.conf
%else
/bin/true
%endif

%install
%make_install DOCDIR=%{_defaultdocdir}/kanku/
mkdir -p %{buildroot}/%{_sysusersdir}/system-user-%{kanku_user}.conf
cp dist/system-user-%{kanku_user}.conf %{buildroot}/%{_sysusersdir}/system-user-%{kanku_user}.conf
%fdupes %{buildroot}/opt/kanku/share
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rckanku-web
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rckanku-worker
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rckanku-dispatcher
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rckanku-scheduler
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rckanku-triggerd

%check
# FIXME
#prove -Ilib t/000_use.t

%files
%exclude /etc
%exclude /usr

%package common
Summary:        Common files for kanku

Recommends:     apache2
Recommends:     osc
Recommends:     perl(IO::Uncompress::UnXz)
Recommends:     perl(YAML::PP::LibYAML)
Requires:       libvirt-daemon-config-network
Requires:       libvirt-daemon-config-nwfilter
Requires:       libvirt-daemon-qemu
Requires:       perl-Plack
Requires:       sudo
Requires:       perl(Config::Tiny)
Requires:       perl(Const::Fast)
Requires:       perl(DBIx::Class)
Requires:       perl(DBIx::Class::Fixtures)
Requires:       perl(DBIx::Class::Migration)
Requires:       perl(Dancer2)
Requires:       perl(Dancer2::Plugin::Auth::Extensible)
Requires:       perl(Dancer2::Plugin::Auth::Extensible::Provider::DBIC)
Requires:       perl(Dancer2::Plugin::DBIC)
Requires:       perl(Dancer2::Plugin::REST)
Requires:       perl(Expect)
Requires:       perl(File::HomeDir)
Requires:       perl(File::LibMagic)
Requires:       perl(IO::Uncompress::UnXz)
Requires:       perl(IPC::Run)
Requires:       perl(JSON::XS)
Requires:       perl(Log::Log4perl)
Requires:       perl(Moose)
Requires:       perl(MooseX::App)
Requires:       perl(MooseX::Singleton)
Requires:       perl(Net::IP)
Requires:       perl(Net::OBS::Client)
Requires:       perl(Libssh::Session)
Requires:       perl(Path::Class)
Requires:       perl(Sys::Virt)
Requires:       perl(Template)
Requires:       perl(Template::Plugin::Filter::ANSIColor)
Requires:       perl(Term::ReadKey)
Requires:       perl(Test::Simple)
Requires:       perl(XML::Structured)
Requires:       perl(XML::XPath)
Requires:       perl(YAML::PP)
# DBD::SQLite is also provided by perl-DBD-SQLite-Amalgamation
# but perl-DBD-SQLite-Amalgamation is breaks with SQL syntax errors
# at job_histroy_sub table
Requires:       perl-DBD-SQLite
Requires:       perl(Archive::Cpio)
Requires:       perl(LWP::Protocol::https)
Requires:       perl(Mail::Sendmail)
Requires:       perl(UUID)
%if 0%{?suse_version}
Requires:       openssl(cli)
%else
Requires:       openssl
%endif

Conflicts:      perl-DBD-SQLite-Amalgamation

%description common
common config and lib files used in kanku

%files common
%doc README.md RELEASE-NOTES-*.md CHANGELOG.md

%dir /usr/lib/kanku
%dir /usr/lib/kanku/lib
%dir /usr/lib/kanku/lib/Kanku
%dir /usr/lib/kanku/lib/Kanku/Daemon

# share contains database related stuff
%dir /usr/share/kanku
/usr/share/kanku/fixtures
/usr/share/kanku/migrations

%attr(755,root,root) /usr/bin/kanku
%attr(755,root,root) /usr/lib/kanku/network-setup.pl

%dir /etc/kanku
%ghost /etc/kanku/config.yml
%dir /etc/kanku/logging/
%config(noreplace) /etc/kanku/logging/console.conf
%config(noreplace) /etc/kanku/logging/network-setup.conf
%config(noreplace) /etc/kanku/logging/default.conf

%dir /etc/kanku/templates
%dir /etc/kanku/templates/cmd
%dir /etc/kanku/templates/cmd/setup
%config /etc/kanku/templates/default-vm.tt2
%config /etc/kanku/templates/with-spice.tt2
%config /etc/kanku/templates/cmd/init.tt2
%config /etc/kanku/templates/cmd/setup/*
%dir    /etc/kanku/templates/examples-vm/
%config /etc/kanku/templates/examples-vm/obs-server-26.tt2
%config /etc/kanku/templates/examples-vm/sles11sp3.tt2
%config /etc/kanku/templates/examples-vm/obs-server.tt2

# %exclude %dir /etc/sudoers.d
# %ghost /etc/sudoers.d/kanku

%exclude %dir /usr
%exclude %dir /usr/bin/
%exclude %dir /usr/sbin/
%exclude %dir /usr/share/
%exclude %dir /usr/lib/

%exclude %dir /etc/profile.d
%config /etc/profile.d/kanku.sh

%dir /usr/lib/kanku/lib/Kanku/NotifyQueue/
/usr/lib/kanku/lib/Kanku/NotifyQueue/*.pm
/usr/lib/kanku/lib/Kanku/Handler/
/usr/lib/kanku/lib/Kanku/Roles/
/usr/lib/kanku/lib/Kanku/Schema/
/usr/lib/kanku/lib/Kanku/Setup/
/usr/lib/kanku/lib/Kanku/Util/
/usr/lib/kanku/lib/Kanku/Util.pm
/usr/lib/kanku/lib/Kanku/Task/
/usr/lib/kanku/lib/OpenStack/
/usr/lib/kanku/lib/Kanku/Config.pm
%dir /usr/lib/kanku/lib/Kanku/Config/
/usr/lib/kanku/lib/Kanku/Config/Defaults.pm
/usr/lib/kanku/lib/Kanku/Handler.pod
/usr/lib/kanku/lib/Kanku/Notifier
/usr/lib/kanku/lib/Kanku/Job.pm
/usr/lib/kanku/lib/Kanku/RabbitMQ.pm
/usr/lib/kanku/lib/Kanku/Schema.pm
/usr/lib/kanku/lib/Kanku/JobList.pm
/usr/lib/kanku/lib/Kanku/Task.pm
/usr/lib/kanku/lib/Kanku/Airbrake.pm
/usr/lib/kanku/lib/Kanku/NotifyQueue.pm
/usr/lib/kanku/lib/Kanku/GPG.pm
/usr/lib/kanku/lib/Kanku/YAML.pm

%dir /usr/lib/kanku/lib/Kanku/WebSocket
/usr/lib/kanku/lib/Kanku/WebSocket/Notification.pm
/usr/lib/kanku/lib/Kanku/WebSocket/Session.pm

%dir /usr/lib/kanku/lib/Kanku/Airbrake
/usr/lib/kanku/lib/Kanku/Airbrake/Dummy.pm

%dir /usr/lib/kanku/lib/Kanku/LibVirt
/usr/lib/kanku/lib/Kanku/LibVirt/HostList.pm

%dir /usr/lib/kanku/lib/Kanku/Dispatch/
/usr/lib/kanku/lib/Kanku/Dispatch/Local.pm

/usr/lib/kanku/lib/Kanku/Test/

%package cli
Summary:        Command line client for kanku
Requires:       kanku-common = %{version}
Requires:       libvirt-client
Requires(pre):  libvirt-daemon libvirt-daemon-driver-qemu
Requires(pre):  sudo
Requires:       (perl(Passwd::Keyring::Gnome) if gnome-keyring)
Requires:       (perl(Passwd::Keyring::KDEWallet) if kwalletd5)
Requires:       perl(IO::Interactive)
Requires:       perl(Net::AMQP::RabbitMQ)

%description cli
Command line client for kanku, mainly used for setup tasks
and in developer mode.

%post cli
    cat >> %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}-something << EOF

WARNING: kankus iptables/ss/netstat handling changed.

Please re-run "kanku setup --devel" if you are using kanku in developer mode.


EOF

%files cli
%dir /usr/share/kanku/views/cli/
%dir /usr/share/kanku/views/cli/rjob
/usr/share/kanku/views/cli/*.tt
/usr/share/kanku/views/cli/rjob/*.tt
/usr/lib/kanku/lib/Kanku/Cli/
/usr/lib/kanku/lib/Kanku/Cli.pm
/usr/lib/kanku/iptables_wrapper
/usr/lib/kanku/ss_netstat_wrapper
/etc/bash_completion.d/kanku.sh
%ghost %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}-something

%package -n system-user-%{kanku_user}
Summary: System user and group %{kanku_user}/%{kanku_group}
Group:    System/Fhs
Provides: user(%{kanku_user})
Provides: group(%{kanku_group})
%if 0%{?suse_version:1}
Requires(pre):  shadow
%endif

%if 0%{?fedora}
%{?sysusers_requires_compat}
%else
%sysusers_requires
%endif

%description -n system-user-%{kanku_user}
This package provides the system account '%{kanku_user}' and group '%{kanku_group}'.


%if 0%{?fedora}
%pre -n system-user-%{kanku_user}
%sysusers_create_compat dist//system-user-%{kanku_user}.conf
%else
%pre -n system-user-%{kanku_user} -f %{kanku_user}.pre
%endif

%files -n system-user-%{kanku_user}
%{_sysusersdir}/system-user-%{kanku_user}.conf

%package common-server
Summary:        Common server files or settings for kanku
Requires(pre):  libvirt-daemon libvirt-daemon-driver-qemu
Requires: user(%{kanku_user})
%if 0%{?fedora}
Requires(pre):  shadow-utils
%else
Requires(pre):  shadow
%endif

%description common-server
This package contains common server files, settings and dependencies
for the kanku server components like kanku-worker, kanku-dispatcher,
kanku-web, kanku-scheduler and kanku-triggerd.

%post common-server
%tmpfiles_create %_tmpfilesdir/kanku.conf

%files common-server
%defattr(-, root, root)
%dir /etc/kanku/jobs
%dir /etc/kanku/job_groups
%dir /etc/kanku/jobs/examples
%config /etc/kanku/jobs/examples/obs-server.yml
%config /etc/kanku/jobs/examples/obs-server-26.yml
%config /etc/kanku/jobs/examples/sles11sp3.yml
%dir %attr(755, kankurun, kanku) /var/lib/kanku
%dir %attr(755, kankurun, kanku) /var/lib/kanku/db
%dir %attr(755, kankurun, kanku) /var/cache/kanku
%ghost %dir %attr(755, kankurun, kanku) /run/kanku
%exclude %dir %_tmpfilesdir
%_tmpfilesdir/kanku.conf

%package web
Summary:        WebUI for kanku
Requires:       kanku-common = %{version}
Requires:       kanku-common-server = %{version}
Requires:       perl(Dancer2::Plugin::WebSocket)
Requires:       perl(Mail::Message::Body::String)
Requires:       perl(Mail::Transport::Send)
Requires:       perl(Net::AMQP::RabbitMQ)
Requires:       perl(Template::Plugin::JSON::Escape)
Requires:       perl(Twiggy)
Requires:       perl(UUID)
%if 0%{?fedora}
Requires:       server(smtp)
%else
Requires:       smtp_daemon
%endif

%description web
WebUI for kanku using perl Dancer

%post web
%systemd_post kanku-web.service

%preun web
%systemd_preun kanku-web.service

%postun web
%systemd_postun_with_restart kanku-web.service

%files web
%attr(755,root,root) /usr/lib/kanku/kanku-app.psgi
%dir %attr(755, kankurun, kanku) /var/lib/kanku/sessions
%dir /usr/share/kanku/views/
%{_unitdir}/kanku-web.service
%{_sbindir}/rckanku-web
/usr/share/kanku/views/admin.tt
/usr/share/kanku/views/guest.tt
/usr/share/kanku/views/index.tt
/usr/share/kanku/views/job.tt
/usr/share/kanku/views/notify.tt
/usr/share/kanku/views/notify_disabled.tt
/usr/share/kanku/views/job_history.tt
/usr/share/kanku/views/job_result.tt
%dir /usr/share/kanku/views/layouts
/usr/share/kanku/views/layouts/main.tt
/usr/share/kanku/views/login.tt
%dir /usr/share/kanku/views/login
/usr/share/kanku/views/login/denied.tt
/usr/share/kanku/views/settings.tt
/usr/share/kanku/views/signup.tt
/usr/share/kanku/views/pwreset.tt
/usr/share/kanku/views/reset_password.tt
/usr/share/kanku/views/worker.tt

%dir /etc/apache2
%dir /etc/apache2/conf.d
%ghost %config (noreplace) /etc/apache2/conf.d/kanku.conf
%config /etc/kanku/jobs/remove-domain.yml
%dir /etc/kanku/dancer

# public contains css/js/bootstrap/jquery etc
/usr/share/kanku/public/
/usr/lib/kanku/lib/Kanku.pm
/usr/lib/kanku/lib/Kanku/REST.pm
/usr/lib/kanku/lib/Kanku/REST
/usr/lib/kanku/lib/Dancer2

%package worker
Summary:        Worker daemon for kanku

Requires:       kanku-common = %{version}
Requires:       kanku-common-server = %{version}
Requires:       perl(Net::AMQP::RabbitMQ)
Requires:       perl(Sys::CPU)
Requires:       perl(Sys::LoadAvg)
Requires:       perl(Sys::MemInfo)
Requires:       perl(UUID)
%if "%{_arch}" == "x86_64" || "%{_arch}" == "i686"
Requires:       qemu-kvm
%endif
%if "%{_arch}" == "aarch64"
Requires:       qemu-arm
%endif
# apache2 is only needed for delivering console logs
Recommends:     apache2

%description worker
A remote worker for kanku based on RabbitMQ.

%post worker
%systemd_post kanku-worker.service

%preun worker
%systemd_preun kanku-worker.service

%postun worker
%systemd_postun_with_restart kanku-worker.service

%files worker
/etc/apache2/conf.d/kanku-worker.conf
%{_unitdir}/kanku-worker.service
%{_sbindir}/rckanku-worker
%{_sbindir}/kanku-worker
/usr/lib/kanku/lib/Kanku/Daemon/Worker.pm

%package dispatcher
Summary:        Dispatcher daemon for kanku

Requires:       kanku-common = %{version}
Requires:       kanku-common-server = %{version}
Requires:       perl(Net::AMQP::RabbitMQ)
Requires(pre):  sudo
Recommends:     rabbitmq-server

%description dispatcher
A dispatcher for kanku based on RabbitMQ.

%post dispatcher
%systemd_post kanku-dispatcher.service

%preun dispatcher
%systemd_preun kanku-dispatcher.service

%postun dispatcher
%systemd_postun_with_restart kanku-dispatcher.service

%files dispatcher
%{_unitdir}/kanku-dispatcher.service
%{_sbindir}/rckanku-dispatcher
%{_sbindir}/kanku-dispatcher
/usr/lib/kanku/lib/Kanku/Daemon/Dispatcher.pm
/usr/lib/kanku/lib/Kanku/Dispatch/RabbitMQ.pm
/usr/share/kanku/views/notifier/

%package scheduler
Summary:        Scheduler daemon for kanku
Requires:       kanku-common = %{version}
Requires:       kanku-common-server = %{version}

%description scheduler
A scheduler for kanku based on RabbitMQ.

%post scheduler
%systemd_post kanku-scheduler.service

%preun scheduler
%systemd_preun kanku-scheduler.service

%postun scheduler
%systemd_postun_with_restart kanku-scheduler.service

%files scheduler
%attr(755,root,root) %{_sbindir}/kanku-scheduler
/usr/lib/kanku/lib/Kanku/Daemon/Scheduler.pm
%{_unitdir}/kanku-scheduler.service
%{_sbindir}/rckanku-scheduler

%package triggerd
Summary:        Trigger daemon for kanku
Requires:       kanku-common = %{version}
Requires:       kanku-common-server = %{version}

%description triggerd
A triggerd for kanku based on RabbitMQ.

%post triggerd
%systemd_post kanku-triggerd.service

%preun triggerd
%systemd_preun kanku-triggerd.service

%postun triggerd
%systemd_postun_with_restart kanku-triggerd.service

%files triggerd
%attr(755,root,root) %{_sbindir}/kanku-triggerd
%{_unitdir}/kanku-triggerd.service
%{_sbindir}/rckanku-triggerd
%dir /usr/lib/kanku/lib/Kanku/Listener
/usr/lib/kanku/lib/Kanku/Daemon/TriggerD.pm
/usr/lib/kanku/lib/Kanku/Listener/RabbitMQ.pm

%package doc
Summary:        Documentation files for kanku

%description doc
This package contains the documentation files for kanku.

%files doc
%{_defaultdocdir}/kanku/

%package urlwrapper
Summary:        Url wrapper for kanku:// urls
Requires:       desktop-file-utils
Requires:       kanku-cli = %{version}
Requires:       shared-mime-info
Obsoletes:      kanku-url-wrapper

%description urlwrapper
A URL wrapper to start kanku from kanku:// urls in the browser.

%post urlwrapper
update-mime-database /usr/share/mime
update-desktop-database

%preun urlwrapper
update-mime-database /usr/share/mime
update-desktop-database

%postun urlwrapper
update-mime-database /usr/share/mime
update-desktop-database

%files urlwrapper
%attr(644,root,root) /usr/share/applications/kanku-urlwrapper.desktop
%attr(644,root,root) /usr/share/mime/packages/kanku.xml
%dir /usr/share/icons/hicolor
%dir /usr/share/icons/hicolor/32x32
%dir /usr/share/icons/hicolor/32x32/apps
/usr/share/icons/hicolor/32x32/apps/kanku.png
%dir /usr/share/icons/hicolor/48x48
%dir /usr/share/icons/hicolor/48x48/apps
/usr/share/icons/hicolor/48x48/apps/kanku.png
%dir /usr/share/icons/hicolor/64x64
%dir /usr/share/icons/hicolor/64x64/apps
/usr/share/icons/hicolor/64x64/apps/kanku.png

%changelog
* Tue Feb 13 2024 FSchreiner@suse.com
- Update to version 0.16.2:
  * [doc] updated changelog ver: 0.16.2
  * [dist] updated debian files to version 0.16.2
  * [dist] moved tmpfile conf to package kanku-common-server
  * [dist] fixed homedir path for user kankurun
  * [handler] CreateDomain: added template to gui_config
  * cleanup POD in Kanku/Handler/CreateDomain
* Mon Feb  5 2024 FSchreiner@suse.com
- Update to version 0.16.1:
  * BUGFIXES
  * [dist] multiple improvements in packaging for rpm based
    distros
* Mon Dec  4 2023 FSchreiner@suse.com
- fixes for 0.16.0 in spec file
  * [dist] added Kanku/Config dir to spec
  * [dist] added K::Config::Defaults to spec
* Mon Dec  4 2023 Frank Schreiner <FSchreiner@suse.com>
- Update to version 0.16.0
  * FEATURES
  * [feature] Implemented HTTP Signature Authentication
  * [feature] Defaults handling migrated to K::Config::Defaults
  * BUGFIXES
  * [cli] cleanup unused packages in urlwrapper
- Update to version 0.15.0
  * FEATURES
  * [cli] configurable apiurl for init and lsi
  * initial version of worker setup
  * [core] waitpid when stopping dispatcher
  * [web] improved login page
  * [web] show error message if user is not logged in
  * [handler] CreateDomain: added vcpu/memory to gui_config
  * [handler] GIT: new option 'recursive' for recursive clones
  * BUGFIXES
  * [handler] OBSServerFrontendTests: fix cleanup temp and logfiles if succeeded
  * [handler] ImageDownload: always set vm_image_file if found vm_image_url
  * [handler] OBSServerFrontendTests: fix stuck test runs
  * [core] fix for rabbitmq reconnect
  * [worker] fixed routing key used for sending job_aborted
  * [handler] GIT: fixed mirror mode
  * [handler] SetupNetwork: fixed pod
  * [core] set job_group start_time before dispatching
  * [core] fixing rabbit retry time
  * [util] VM: changed default accessmode_9p to 'squash'
  * [handler] OBSServerFrontendTests: changed to user kanku and use local path
  * [handler] OBSServerFrontendTests: split commands
  * [dist] set timeout for kanku-worker.service to 90sec
  * [dispatcher] kill dispatcher process running dead jobs
  * [dispatcher] clean up dead job groups on dispatcher startup/shutdown
  * [worker] send aborted_job to correct job queue
  * [web] return error if data for job_group rest call is HASH
  * [worker] do not return before destroying queue
  * [examples] updated KankuFile.openQA
  * [handler] SetupNetwork: added timeout
* Tue Jan 10 2023 FSchreiner@suse.com
- Update to version 0.14.0:
  * FEATURES
  * [web] first working version of job_group triggers via token auth
  * [web] creation time in job info
  * [core] configurable git parameters for job groups
  * [dispatcher] locking for job groups
  * [cli] rtrigger: added trigger for job_group's
  * [dist] added GitLab::WebHook example to dancer config template
  * [core] replaced Net::SSH2 with Libssh::Session
  * [examples] install job group examples in sostw job in KankuFile
  * [handler] PreparSSH: global config for 'public_key_files' in kanku-config.yml
  * [core] dispatcher cleanup jobs waiting for recursivly
  * BUGFIXES
  * [core] catch rabbitmq connection error and reconnect
  * [dispatcher] fix data caching issues with job groups
  * [core] fix 'uninitialized value' issues
  * [web] skipped jobs showed as warnings
  * [setup] copy certs only if dest does not exists
  * [web] automatically enable all jobs in job_group which are not exlicitly disabled
  * [core] added timeout_nodata for SSH
  * [handler] OBSServerFrontendTests: fix timeout problem
  * [handler] CreateDomain: die if no vm_image_file in ctx
  * [cli] avoid 'uninitialized' warnings in rjob when no filter is set
* Mon Dec  5 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build only for supported arch.
  See 'etc/templates/default-vm.tt2.$ARCH'
* Thu Oct 13 2022 FSchreiner@suse.com
- Update to version 0.13.0:
  * [doc] updated changelog ver: 0.13.0
  * [doc] updated release notes 0.13.0
  * [core] recreate queues named 'amq.*' without a dedicate queue name
  * [core] refactored rabbmitmq handling in worker and dispatcher
  * [handler] Reboot: new option 'login_timeout' to wait for console
  * [dist] change copy in Makefile from '-av' to '-rv'
  * [handler] SaltSSH: added multiple attributes
  * [dist] changed 'cp -av' to 'cp -rv'
  * [dist] added RELEASE-NOTES and CHANGELOG to spec file
  * [doc] updated changelog
  * [doc] updated release notes 0.12.7
  * [doc] updated release notes 0.12.6
  * [doc] updated release notes 0.12.5
  * [doc] updated release notes 0.12.4
  * [doc] updated release notes 0.12.3
  * [doc] updated release notes 0.12.2
  * [doc] updated release notes 0.12.1
  * [doc] updated release notes 0.12.0
  * [contrib] removed p2h - already in branch gh-pages-src
  * [dist] added .statocles to .gitignore
  * [dist] removed kanku-web.log from default logging conf
  * [dist] remove logrotate config - now done with journald
  * [cli] ssh: new parameter --x11_forward/-X to enable ssh x11 forwarding
* Thu Jun 23 2022 FSchreiner@suse.com
- Update to version 0.12.7:
  * [handler] fixing users
  * [cli] up: fixed __ALL__
* Wed Jun 22 2022 FSchreiner@suse.com
- Update to version 0.12.6:
  * [dist] updated KankuFile.ubuntu to jammy
  * [dist] updated KankuFile.ubuntu to focal
  * [examples] new KankuFile for vmdk
  * [cli] up: removed debug output
  * [core] fixed kanku job sostw
  * [core] updated TODO
  * [cli] up: new job handling
  * [handler] added K::H::CopyProfile
  * added changelog to kanku-common and kanku-cli
* Thu Jun  9 2022 FSchreiner@suse.com
- Update to version 0.12.5:
  * [cli] up: new alias for '--skip_check_domain' -> '-S'
  * [cli] ssh: new option '--agent_forward' aliase '-A'
  * [cli] new option '--skip_check_domain' for 'kanku up'
  * [util] use cache='unsafe' only for vmdk
  * [dist] fixed order of iptables rules when using multiple networks
  * [handler] changed get_ipaddress in SetupNetwork to console
* Mon May  9 2022 FSchreiner@suse.com
- Update to version 0.12.4:
  * [util] enable cache=unsafe for all disk images
  * [web] fixed 'scroll to top' button
* Mon Mar 14 2022 FSchreiner@suse.com
- Update to version 0.12.3:
  * [web] fix outdated cached settings in "Job Groups"
  * [cli] added job_groups to check_configs command
  * [core] fixed config read
  * [core] improvments for config file handling
  * [core] improved iptables/ss/netstat handling
  * Fixes #boo 1196604
  * [setup] removed backup of sudoers file
  * removed ssh_user from KankuFile
  * [dist] change default logging to stderr/journald
  * [util] VM::Image - use new buffer size while uncompressing
  * [common] fixed x-scheme-handler_kanku
  * [handler][bugfix] central config for host_interfaces in PortForward
* Fri Feb 18 2022 FSchreiner@suse.com
- Update to version 0.12.2:
  * [web][bugfix] filter iptable rules by domain name
* Wed Feb 16 2022 FSchreiner@suse.com
- Update to version 0.12.1:
  * [core][feature] new systemd service kanku-iptables for master server
* Wed Feb  9 2022 Frank Schreiner <FSchreiner@suse.com>
- Update to version 0.12.0:
  * see RELEASE-NOTES-0.12.0.md in the doc dir
* Thu Nov 18 2021 FSchreiner@suse.com
- Update to version 0.11.0:
  * see RELEASE-NOTES-0.11.0.md in the doc dir of your packages
  * PATCH removed 0001_dancer-config.patch - included in new
    release
* Sun Oct 24 2021 Frank Schreiner <FSchreiner@suse.com>
- fix dancer config template - removed duplicate session key
  * PATCH added 0001_dancer-config.patch
* Sun Jul 11 2021 FSchreiner@suse.com
- Update to version 0.10.4:
  * [dist] spec file cleanup
* Sat Jun 12 2021 FSchreiner@suse.com
- Update to version 0.10.4:
  * [handler] PrepareSSH - added all known default pub key file used by ssh
  * [handler] OBSCheck changed default for use_oscrc to 0
  * [notifier] new notifier NSCAng
  * [notifier] removed unused variable in NSCA
  * [dist] fixed duplicate key in kanku-config.yml.tt2
  * [cli] basic version of check_configs command
  * [core] switched logging to trace
* Thu Apr 15 2021 FSchreiner@suse.com
- Update to version 0.10.3:
  * [dist] bind "Requires: kanku*" to specific version
  * [web] fix 'Subroutine redefined' in Kanku::REST
  * [web] help for guest page
  * [dist] removed help from views
  * [web] help page as modal window
  * [dist] added help page to spec
  * [web] help page for job_history
  * [web] fix tooltips in job page
  * [web] more explainations in guest.js
  * [web] fix for showDetails in common.js
  * [handler] fixed ssh for Fedora 33
  * [util] fix for Fedora login behavior
  * [web] job id in comment title
  * [web] improved tooltips
  * [web] fix closeModal in common.js
  * [web] fix route handling when retrigger a job
  * [web] refresh button in jobs_results page
* Sat Feb 13 2021 FSchreiner@suse.com
- Update to version 0.10.2:
  * [dist] fixed typo in spec
  * [dist] fixed spec for i686
  * [dist] added default-vm.tt2.i686
  * [util] improved terminal handling in VM::Console for Debian Unstable
  * [dist] added debian files to extract via service
  * [dist] removed debian files - use DEBTRANSFORM
  * [dist] updated debian changelog
  * [setup] fixed network_name in distributed setup
  * [dist] fixed missing quotes for _arch
  * removed TODOs and added req for qemu
  * [dist] imported changes in spec file from jengelh
* Thu Jan 28 2021 Frank Schreiner <FSchreiner@suse.com>
- removed TODO's from spec file
* Mon Jan 25 2021 Jan Engelhardt <jengelh@inai.de>
- Trim marketing wording from descriptions.
- Remove old build recipe constructs.
* Thu Jan 14 2021 Frank Schreiner <FSchreiner@suse.com>
- initial version of kanku rpm package (0.10.0)
